@@ -29,7 +29,7 @@ from pysollib.help import help_about, help_html
 from pysollib.mfxutil import Struct, openURL
 from pysollib.mfxutil import print_err
 from pysollib.mygettext import _
-from pysollib.pysolrandom import constructRandom
+from pysollib.pysolrandom import construct_random
 from pysollib.pysoltk import AllGames_StatsDialog, SingleGame_StatsDialog
 from pysollib.pysoltk import ColorsDialog
 from pysollib.pysoltk import EditTextDialog
@@ -251,7 +251,7 @@ class PysolMenubar(PysolMenubarTk):
 
     def _mNewGameBySeed(self, seed, origin):
         try:
-            random = constructRandom(seed)
+            random = construct_random(seed)
             if random is None:
                 return
             id = self.game.id
@@ -519,7 +519,8 @@ class PysolMenubar(PysolMenubarTk):
                     text += os.linesep
                 enc = locale.getpreferredencoding()
                 try:
-                    open(fn, 'a').write(text.encode(enc, 'replace'))
+                    with open(fn, 'at') as fh:
+                        fh.write(text.encode(enc, 'replace'))
                 except Exception as err:
                     d = MfxExceptionDialog(
                         self.top, err,
@@ -847,7 +848,8 @@ class PysolMenubar(PysolMenubarTk):
     def mPlayNextMusic(self, *args):
         if self._cancelDrag(break_pause=False):
             return
-        if self.app.audio and self.app.opt.sound_music_volume > 0:
+        if (self.app.audio and self.app.music and
+                self.app.opt.sound_music_volume > 0):
             self.app.audio.playNextMusic()
             if 1 and DEBUG:
                 index = self.app.audio.getMusicInfo()
