@@ -33,6 +33,7 @@ from pysollib.actions import PysolMenubar
 from pysollib.actions import PysolToolbar
 from pysollib.app_stat_result import GameStatResult
 from pysollib.app_statistics import Statistics
+from pysollib.cardsetparser import read_cardset_config
 from pysollib.gamedb import GAME_DB, GI, loadGame
 from pysollib.help import destroy_help_html, help_about
 from pysollib.images import Images, SubsampledImages
@@ -43,7 +44,7 @@ from pysollib.mfxutil import latin1_normalize, print_err
 from pysollib.mfxutil import pickle, unpickle
 from pysollib.mygettext import _
 from pysollib.options import Options
-from pysollib.pysolrandom import PysolRandom, constructRandom
+from pysollib.pysolrandom import PysolRandom, construct_random
 from pysollib.pysoltk import HTMLViewer
 from pysollib.pysoltk import HelpStatusbar, PysolStatusbar
 from pysollib.pysoltk import MfxDialog, MfxExceptionDialog, MfxMessageDialog
@@ -53,7 +54,7 @@ from pysollib.pysoltk import SelectCardsetDialogWithPreview
 from pysollib.pysoltk import SelectDialogTreeData
 from pysollib.pysoltk import destroy_find_card_dialog
 from pysollib.pysoltk import loadImage, wm_withdraw
-from pysollib.resource import CSI, Cardset, CardsetConfig, CardsetManager
+from pysollib.resource import CSI, CardsetManager
 from pysollib.resource import Music, MusicManager
 from pysollib.resource import Sample, SampleManager
 from pysollib.resource import Tile, TileManager
@@ -336,7 +337,7 @@ class Application:
                     self.nextgame.id = gameid
                     deal = self.commandline.deal
                     self.nextgame.random = \
-                        None if deal is None else constructRandom(deal)
+                        None if deal is None else construct_random(deal)
             elif self.commandline.gameid is not None:
                 self.nextgame.id, self.nextgame.random = \
                     self.commandline.gameid, None
@@ -772,56 +773,60 @@ class Application:
             t0 = t1 = "Unknown"
         return t0, t1
 
-    def getCompatibleCardset(self, gi, cs):
+    def getCompatibleCardset(self, gi, cs, trychange=True):
         if gi is None:
-            return cs, 1
+            return cs, 1, None
+        t = self.checkCompatibleCardsetType(gi, cs)
         # try current
         if cs:
-            t = self.checkCompatibleCardsetType(gi, cs)
             if not t[1]:
-                return cs, 1
-        # try by gameid / category
-        for key, flag in (((1, gi.id), 8), (gi.category, 4)):
-            c = self.opt.cardset.get(key)
-            if not c or len(c) != 2:
-                continue
-            cs = self.cardset_manager.getByName(c[0])
-            if not cs:
-                continue
-            t = self.checkCompatibleCardsetType(gi, cs)
-            if not t[1]:
-                cs.updateCardback(backname=c[1])
-                return cs, flag
+                return cs, 1, t
+        if trychange:
+            # try by gameid / category
+            for key, flag in (((1, gi.id), 8), (gi.category, 4)):
+                c = self.opt.cardset.get(key)
+                if not c or len(c) != 2:
+                    continue
+                cs = self.cardset_manager.getByName(c[0])
+                if not cs:
+                    continue
+                t = self.checkCompatibleCardsetType(gi, cs)
+                if not t[1]:
+                    cs.updateCardback(backname=c[1])
+                    return cs, flag, t
         # ask
-        return None, 0
+        return None, 0, t
 
     def requestCompatibleCardsetType(self, id):
         gi = self.getGameInfo(id)
         #
-        cs, cs_update_flag = self.getCompatibleCardset(gi, self.cardset)
+        cs, cs_update_flag, t = self.getCompatibleCardset(gi, self.cardset)
         if cs is self.cardset:
             return 0
         if cs is not None:
             self.loadCardset(cs, update=1)
             return 1
-        #
-        t = self.checkCompatibleCardsetType(gi, self.cardset)
-        MfxMessageDialog(
-            self.top, title=_("Incompatible cardset"),
-            bitmap="warning",
-            text=_('''The currently selected cardset %(cardset)s
-is not compatible with the game
-%(game)s
 
-Please select a %(correct_type)s type cardset.
-''') % {'cardset': self.cardset.name, 'game': gi.name, 'correct_type': t[0]},
-            strings=(_("&OK"),), default=0)
+        self.requestCompatibleCardsetTypeDialog(self.cardset, gi, t)
+
         cs = self.__selectCardsetDialog(t)
         if cs is None:
             return -1
         self.loadCardset(cs, id=id)
         return 1
 
+    def requestCompatibleCardsetTypeDialog(self, cardset, gi, t):
+        MfxMessageDialog(
+            self.top, title=_("Incompatible cardset"),
+            bitmap="warning",
+            text=_('''The currently selected cardset %(cardset)s
+        is not compatible with the game
+        %(game)s
+
+        Please select a %(correct_type)s type cardset.
+        ''') % {'cardset': cardset.name, 'game': gi.name,
+                'correct_type': t[0]}, strings=(_("&OK"),), default=0)
+
     def selectCardset(self, title, key):
         d = SelectCardsetDialogWithPreview(
             self.top, title=title, app=self,
@@ -832,7 +837,8 @@ Please select a %(correct_type)s type cardset.
         changed = False
         if USE_PIL:
             if (self.opt.scale_x, self.opt.scale_y,
-                self.opt.auto_scale, self.opt.preserve_aspect_ratio) != \
+                self.opt.auto_scale, self.opt.spread_stacks,
+                self.opt.preserve_aspect_ratio) != \
                 d.scale_values or \
                     (cs.CARD_XOFFSET, cs.CARD_YOFFSET) != d.cardset_values:
                 changed = True
@@ -842,6 +848,7 @@ Please select a %(correct_type)s type cardset.
             (self.opt.scale_x,
              self.opt.scale_y,
              self.opt.auto_scale,
+             self.opt.spread_stacks,
              self.opt.preserve_aspect_ratio) = d.scale_values
             if not self.opt.auto_scale:
                 self.images.resize(self.opt.scale_x, self.opt.scale_y)
@@ -1070,176 +1077,56 @@ Please select a %(correct_type)s type cardset.
 
     # read & parse a cardset config.txt file - see class Cardset in resource.py
     def _readCardsetConfig(self, dirname, filename):
-        with open(filename, "r") as f:
-            lines = f.readlines()
-        lines = [line.strip() for line in lines]
-        if not lines[0].startswith("PySol"):
-            return None
-        config = CardsetConfig()
-        if not self._parseCardsetConfig(config, lines):
-            # print filename, 'invalid config'
-            return None
-        if config.CARDD > self.top.winfo_screendepth():
-            return None
-        cs = Cardset()
-        cs.dir = dirname
-        cs.update(config.__dict__)
-        return cs
-
-    def _parseCardsetConfig(self, cs, line):
-        def perr(line, field=None, msg=''):
-            if not DEBUG:
-                return
-            if field:
-                print_err('_parseCardsetConfig error: line #%d, field #%d %s'
-                          % (line, field, msg))
-            else:
-                print_err('_parseCardsetConfig error: line #%d: %s'
-                          % (line, msg))
-        if len(line) < 6:
-            perr(1, msg='number of lines')
-            return 0
-        # line[0]: magic identifier, possible version information
-        fields = [f.strip() for f in line[0].split(';')]
-        if len(fields) >= 2:
-            m = re.search(r"^(\d+)$", fields[1])
-            if m:
-                cs.version = int(m.group(1))
-        if cs.version >= 3:
-            if len(fields) < 5:
-                perr(1, msg='number of fields')
-                return 0
-            cs.ext = fields[2]
-            m = re.search(r"^(\d+)$", fields[3])
-            if not m:
-                perr(1, 3, 'not integer')
-                return 0
-            cs.type = int(m.group(1))
-            m = re.search(r"^(\d+)$", fields[4])
-            if not m:
-                perr(1, 4, 'not integer')
-                return 0
-            cs.ncards = int(m.group(1))
-        if cs.version >= 4:
-            if len(fields) < 6:
-                perr(1, msg='number of fields')
-                return 0
-            styles = fields[5].split(",")
-            for s in styles:
-                m = re.search(r"^\s*(\d+)\s*$", s)
-                if not m:
-                    perr(1, 5, 'not integer')
-                    return 0
-                s = int(m.group(1))
-                if s not in cs.styles:
-                    cs.styles.append(s)
-        if cs.version >= 5:
-            if len(fields) < 7:
-                perr(1, msg='number of fields')
-                return 0
-            m = re.search(r"^(\d+)$", fields[6])
-            if not m:
-                perr(1, 6, 'not integer')
-                return 0
-            cs.year = int(m.group(1))
-        if len(cs.ext) < 2 or cs.ext[0] != ".":
-            perr(1, msg='invalid extention')
-            return 0
-        # line[1]: identifier/name
-        if not line[1]:
-            perr(2, msg='empty line')
-            return 0
-        cs.ident = line[1]
-        m = re.search(r"^(.*;)?([^;]+)$", cs.ident)
-        if not m:
-            perr(2, msg='invalid format')
-            return 0
-        cs.name = m.group(2).strip()
-        # line[2]: CARDW, CARDH, CARDD
-        m = re.search(r"^(\d+)\s+(\d+)\s+(\d+)", line[2])
-        if not m:
-            perr(3, msg='invalid format')
-            return 0
-        cs.CARDW, cs.CARDH, cs.CARDD = \
-            int(m.group(1)), int(m.group(2)), int(m.group(3))
-        # line[3]: CARD_UP_YOFFSET, CARD_DOWN_YOFFSET,
-        # SHADOW_XOFFSET, SHADOW_YOFFSET
-        m = re.search(r"^(\d+)\s+(\d+)\s+(\d+)\s+(\d+)", line[3])
-        if not m:
-            perr(4, msg='invalid format')
-            return 0
-        cs.CARD_XOFFSET = int(m.group(1))
-        cs.CARD_YOFFSET = int(m.group(2))
-        cs.SHADOW_XOFFSET = int(m.group(3))
-        cs.SHADOW_YOFFSET = int(m.group(4))
-        # line[4]: default background
-        back = line[4]
-        if not back:
-            perr(5, msg='empty line')
-            return 0
-        # line[5]: all available backgrounds
-        cs.backnames = [f.strip() for f in line[5].split(';')]
-        if back in cs.backnames:
-            cs.backindex = cs.backnames.index(back)
-        else:
-            cs.backnames.insert(0, back)
-            cs.backindex = 0
+        cs = read_cardset_config(dirname, filename)
         # set offsets from options.cfg
         if cs.ident in self.opt.offsets:
             cs.CARD_XOFFSET, cs.CARD_YOFFSET = self.opt.offsets[cs.ident]
-        # if cs.type != 1: print cs.type, cs.name
-        return 1
+        return cs
 
     def initCardsets(self):
+        """Load all valid cardset config.txt files and ignore invalid ones.
+        """
+        screendepth = self.top.winfo_screendepth()
         manager = self.cardset_manager
         # find all available cardsets
         dirs = manager.getSearchDirs(self, ("cardsets", ""), "PYSOL_CARDSETS")
         if DEBUG:
             dirs += manager.getSearchDirs(self, "cardsets-*")
-        # print dirs
-        found, t = [], {}
-        fnames = {}  # (to check for duplicates)
+        found = []
+        found_names = []  # (to check for duplicates)
         for dirname in dirs:
-            dirname = dirname.strip()
             try:
-                names = []
-                if dirname and os.path.isdir(dirname) and dirname not in t:
-                    t[dirname] = 1
-                    names = os.listdir(dirname)
-                    names.sort()
-                for name in names:
-                    if not name.startswith('cardset-'):
-                        continue
-                    d = os.path.join(dirname, name)
-                    if not os.path.isdir(d):
-                        continue
-                    f = os.path.join(d, "config.txt")
-                    if os.path.isfile(f):
-                        try:
-                            cs = self._readCardsetConfig(d, f)
-                            if cs:
-                                # from pprint import pprint
-                                # print cs.name
-                                # pprint(cs.__dict__)
-                                back = cs.backnames[cs.backindex]
-                                f1 = os.path.join(d, back)
-                                f2 = os.path.join(d, "shade" + cs.ext)
-                                if (cs.ext in IMAGE_EXTENSIONS and
-                                        cs.name not in fnames and
-                                        os.path.isfile(f1) and
-                                        os.path.isfile(f2)):
-                                    found.append(cs)
-                                    # print '+', cs.name
-                                    fnames[cs.name] = 1
-                            else:
-                                print_err('fail _readCardsetConfig: %s %s'
-                                          % (d, f))
-                                pass
-                        except Exception:
-                            # traceback.print_exc()
-                            pass
+                subdirs = [os.path.join(dirname, subdir)
+                           for subdir in os.listdir(dirname)
+                           if subdir.startswith('cardset-')]
             except EnvironmentError:
-                pass
+                traceback.print_exc()
+                continue
+            subdirs.sort()
+            for d in subdirs:
+                config_txt_path = os.path.join(d, "config.txt")
+                if not os.path.isfile(config_txt_path):
+                    continue
+                try:
+                    cs = self._readCardsetConfig(d, config_txt_path)
+                except Exception:
+                    traceback.print_exc()
+                    cs = None
+                if not cs:
+                    print_err('failed to parse cardset file: %s'
+                              % config_txt_path)
+                    continue
+                back = cs.backnames[cs.backindex]
+                back_im_path = os.path.join(d, back)
+                shade_im_path = os.path.join(d, "shade" + cs.ext)
+                if (cs.name not in found_names and
+                        cs.ext in IMAGE_EXTENSIONS and
+                        cs.CARDD <= screendepth and
+                        os.path.isfile(back_im_path) and
+                        os.path.isfile(shade_im_path)):
+                    found.append(cs)
+                    found_names.append(cs.name)
+
         # register cardsets
         for obj in found:
             if not manager.getByName(obj.name):
