@@ -21,19 +21,11 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-
-# PySol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
 from pysollib.game import Game
-from pysollib.layout import Layout
-from pysollib.hint import DefaultHint, CautiousDefaultHint
-
+from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.games.gypsy import DieRussische_Foundation
-
-from pysollib.util import ACE, ANY_RANK, ANY_SUIT, KING, NO_RANK, \
-        UNLIMITED_MOVES, UNLIMITED_REDEALS
-
+from pysollib.hint import CautiousDefaultHint, DefaultHint
+from pysollib.layout import Layout
 from pysollib.stack import \
         AC_FoundationStack, \
         AC_RowStack, \
@@ -45,17 +37,15 @@ from pysollib.stack import \
         SS_RowStack, \
         Spider_SS_RowStack, \
         Stack, \
+        StackWrapper, \
         TalonStack, \
         UD_AC_RowStack, \
         WasteStack, \
-        WasteTalonStack, \
-        StackWrapper
+        WasteTalonStack
+from pysollib.util import ACE, ANY_RANK, ANY_SUIT, KING, NO_RANK, \
+        UNLIMITED_MOVES, UNLIMITED_REDEALS
 
 
-# ************************************************************************
-# *
-# ************************************************************************
-
 class FortyThieves_Hint(CautiousDefaultHint):
     # FIXME: demo is not too clever in this game
     pass
@@ -172,6 +162,8 @@ class FortyThieves(Game):
 # * Big Courtyard
 # * San Juan Hill
 # * Famous Fifty
+# * Sixty Thieves
+# * Eighty Thieves
 # *   rows build down by suit
 # ************************************************************************
 
@@ -280,6 +272,20 @@ class FamousFifty(FortyThieves):
     DEAL = (0, 5)
 
 
+class SixtyThieves(FortyThieves):
+    DEAL = (0, 5)
+
+    def createGame(self):
+        FortyThieves.createGame(self, rows=12, playcards=16, XCARDS=96)
+
+
+class EightyThieves(FortyThieves):
+    DEAL = (0, 8)
+
+    def createGame(self):
+        FortyThieves.createGame(self, rows=10, playcards=16, XCARDS=128)
+
+
 # ************************************************************************
 # * Deuces
 # ************************************************************************
@@ -1359,3 +1365,7 @@ registerGame(GameInfo(751, BlindPatience, "Blind Patience",
 registerGame(GameInfo(765, Foothold, "Foothold",
                       GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 2, 0,
                       GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(775, SixtyThieves, "Sixty Thieves",
+                      GI.GT_FORTY_THIEVES, 3, 0, GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(776, EightyThieves, "Eighty Thieves",
+                      GI.GT_FORTY_THIEVES, 4, 0, GI.SL_MOSTLY_SKILL))
