@@ -21,20 +21,13 @@
 #
 # ---------------------------------------------------------------------------
 
-# imports
-
-# PySol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.mfxutil import kwdefault
 from pysollib.game import Game
-from pysollib.layout import Layout
-from pysollib.hint import DefaultHint
-from pysollib.hint import FreeCellType_Hint, FreeCellSolverWrapper
-
+from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.games.spider import Spider_AC_Foundation
-
-from pysollib.util import ACE, ANY_SUIT, KING, NO_RANK, UNLIMITED_CARDS
-
+from pysollib.hint import DefaultHint
+from pysollib.hint import FreeCellSolverWrapper, FreeCellType_Hint
+from pysollib.layout import Layout
+from pysollib.mfxutil import kwdefault
 from pysollib.stack import \
         AC_FoundationStack, \
         AC_RowStack, \
@@ -48,10 +41,11 @@ from pysollib.stack import \
         ReserveStack, \
         SS_FoundationStack, \
         Stack, \
+        StackWrapper, \
         SuperMoveAC_RowStack, \
         SuperMoveRK_RowStack, \
-        isAlternateColorSequence, \
-        StackWrapper
+        isAlternateColorSequence
+from pysollib.util import ACE, ANY_SUIT, KING, NO_RANK, UNLIMITED_CARDS
 
 # ************************************************************************
 # * FreeCell
@@ -654,10 +648,11 @@ registerGame(GameInfo(5, RelaxedFreeCell, "Relaxed FreeCell",
                       GI.GT_FREECELL | GI.GT_RELAXED | GI.GT_OPEN, 1, 0,
                       GI.SL_SKILL))
 registerGame(GameInfo(8, FreeCell, "FreeCell",
+                      GI.GT_FREECELL | GI.GT_OPEN, 1, 0, GI.SL_SKILL,
+                      altnames=("Four Free")))
+registerGame(GameInfo(1901, ZeroFcFreeCell, "FreeCell (No Reserve)",
                       GI.GT_FREECELL | GI.GT_OPEN, 1, 0, GI.SL_SKILL))
-registerGame(GameInfo(1901, ZeroFcFreeCell, "FreeCell with Zero Reserves",
-                      GI.GT_FREECELL | GI.GT_OPEN, 1, 0, GI.SL_SKILL))
-registerGame(GameInfo(1900, PairFcFreeCell, "FreeCell with Two Reserves",
+registerGame(GameInfo(1900, PairFcFreeCell, "FreeCell (2 Reserves)",
                       GI.GT_FREECELL | GI.GT_OPEN, 1, 0, GI.SL_SKILL))
 registerGame(GameInfo(46, ForeCell, "ForeCell",
                       GI.GT_FREECELL | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))
@@ -669,8 +664,7 @@ registerGame(GameInfo(264, DoubleFreecell, "Double FreeCell",
 registerGame(GameInfo(265, TripleFreecell, "Triple FreeCell",
                       GI.GT_FREECELL | GI.GT_OPEN, 3, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(336, ChallengeFreeCell, "Challenge FreeCell",
-                      GI.GT_FREECELL | GI.GT_OPEN, 1, 0, GI.SL_SKILL,
-                      rules_filename='freecell.html'))
+                      GI.GT_FREECELL | GI.GT_OPEN, 1, 0, GI.SL_SKILL))
 registerGame(GameInfo(337, SuperChallengeFreeCell, "Super Challenge FreeCell",
                       GI.GT_FREECELL | GI.GT_OPEN, 1, 0, GI.SL_SKILL))
 registerGame(GameInfo(363, Spidercells, "Spidercells",
