@@ -112,6 +112,7 @@ class MonteCarlo(Game):
     Hint_Class = MonteCarlo_Hint
 
     FILL_STACKS_AFTER_DROP = False
+    FILL_STACKS_BEFORE_SHIFT = False
 
     #
     # game layout
@@ -173,15 +174,10 @@ class MonteCarlo(Game):
             return diff in (-6, -5, -4, -1, 1, 4, 5, 6)
 
     def fillEmptyStacks(self):
-        free, n = 0, 0
+        n = 0
         self.startDealSample()
-        for r in self.s.rows:
-            assert len(r.cards) <= 1
-            if not r.cards:
-                free += 1
-            elif free > 0:
-                to_stack = self.allstacks[r.id - free]
-                self.moveMove(1, r, to_stack, frames=4, shadow=0)
+        free = self.shiftCards()
+        remcards = free > len(self.s.talon.cards) > 0
         if free > 0:
             for r in self.s.rows:
                 if not r.cards:
@@ -190,9 +186,23 @@ class MonteCarlo(Game):
                     self.flipMove(self.s.talon)
                     self.moveMove(1, self.s.talon, r)
                     n += 1
+        if remcards and self.FILL_STACKS_BEFORE_SHIFT:
+            self.shiftCards()
         self.stopSamples()
         return n + free
 
+    def shiftCards(self):
+        free = 0
+        for r in self.s.rows:
+            assert len(r.cards) <= 1
+            if not r.cards:
+                free += 1
+            elif free > 0 and (not self.FILL_STACKS_BEFORE_SHIFT
+                               or not self.s.talon.cards):
+                to_stack = self.allstacks[r.id - free]
+                self.moveMove(1, r, to_stack, frames=4, shadow=0)
+        return free
+
 
 class MonteCarlo2Decks(MonteCarlo):
     pass
@@ -261,6 +271,31 @@ class SimpleCarlo(MonteCarlo):
         return 0 <= stack1.id <= 24 and 0 <= stack2.id <= 24
 
 
+# ************************************************************************
+# * Quatorze
+# ************************************************************************
+
+class Quatorze_RowStack(MonteCarlo_RowStack):
+    def acceptsCards(self, from_stack, cards):
+        if not OpenStack.acceptsCards(self, from_stack, cards):
+            return False
+        # check the rank
+        if self.cards[-1].rank + cards[0].rank != 12:
+            return False
+        # now look if the stacks are neighbours
+        return self.game.isNeighbour(from_stack, self)
+
+
+class Quatorze(MonteCarlo):
+    RowStack_Class = Quatorze_RowStack
+    FILL_STACKS_AFTER_DROP = True
+    FILL_STACKS_BEFORE_SHIFT = True
+
+    def isNeighbour(self, stack1, stack2):
+        return (stack1.id // 5 == stack2.id // 5 or
+                stack1.id % 5 == stack2.id % 5)
+
+
 # ************************************************************************
 # * Simple Pairs
 # ************************************************************************
@@ -432,6 +467,7 @@ class Fourteen(Game):
 
 # ************************************************************************
 # * Nestor
+# * Double Nestor
 # ************************************************************************
 
 class Nestor_RowStack(MonteCarlo_RowStack):
@@ -448,6 +484,9 @@ class Nestor(Game):
 
     FILL_STACKS_AFTER_DROP = False
 
+    COLS = 8
+    COLCARDS = 6
+
     #
     # game layout
     #
@@ -457,16 +496,17 @@ class Nestor(Game):
         l, s = Layout(self), self.s
 
         # set window
-        self.setSize(l.XM+8*l.XS, l.YM+2*l.YS+12*l.YOFFSET)
+        self.setSize(l.XM + self.COLS * l.XS,
+                     l.YM + 2 * l.YS + (self.COLCARDS + 6) * l.YOFFSET)
 
         # create stacks
         x, y = l.XM, l.YM
-        for i in range(8):
+        for i in range(self.COLS):
             s.rows.append(self.RowStack_Class(x, y, self,
                                               max_move=1, max_accept=1,
                                               dir=0, base_rank=NO_RANK))
             x += l.XS
-        x, y = l.XM+2*l.XS, self.height-l.YS
+        x, y = l.XM + ((self.COLS / 2) - 2) * l.XS, self.height-l.YS
         for i in range(4):
             s.rows.append(self.RowStack_Class(x, y, self,
                                               max_move=1, max_accept=1,
@@ -474,7 +514,8 @@ class Nestor(Game):
             x += l.XS
         x, y = self.width-l.XS, self.height-l.YS
         s.foundations.append(self.Foundation_Class(x, y, self, suit=ANY_SUIT,
-                             max_move=0, max_cards=52, base_rank=ANY_RANK))
+                             max_move=0, max_cards=(52 * self.gameinfo.decks),
+                                                   base_rank=ANY_RANK))
         l.createText(s.foundations[0], "n")
         x, y = l.XM, self.height - l.YS
         s.talon = InitialDealTalonStack(x, y, self)
@@ -495,23 +536,25 @@ class Nestor(Game):
 
     def _shuffleHook(self, cards):
         # no row will have two cards of the same rank
-        for i in range(8):
+        for i in range(self.COLS):
             for t in range(1000):  # just in case
-                j = self._checkRow(cards[i*6:(i+1)*6])
+                j = self._checkRow(cards[i * self.COLCARDS:(i + 1)
+                                   * self.COLCARDS])
                 if j < 0:
                     break
-                j += i*6
-                k = self.random.choice(list(range((i+1)*6, 52)))
+                j += i * self.COLCARDS
+                k = self.random.choice(list(range((i+1) * self.COLCARDS,
+                                                  (52 * self.gameinfo.decks))))
                 cards[j], cards[k] = cards[k], cards[j]
         cards.reverse()
         return cards
 
     def startGame(self):
-        for r in self.s.rows[:8]:
-            for j in range(6):
+        for r in self.s.rows[:self.COLS]:
+            for j in range(self.COLCARDS):
                 self.s.talon.dealRow(rows=[r], frames=0)
         self.startDealSample()
-        self.s.talon.dealRow(rows=self.s.rows[8:])
+        self.s.talon.dealRow(rows=self.s.rows[self.COLS:])
 
     def getAutoStacks(self, event=None):
         return ((), (), self.sg.dropstacks)
@@ -520,6 +563,11 @@ class Nestor(Game):
         return card1.rank == card2.rank
 
 
+class DoubleNestor(Nestor):
+    COLS = 10
+    COLCARDS = 10
+
+
 # ************************************************************************
 # * Vertical
 # ************************************************************************
@@ -928,3 +976,8 @@ registerGame(GameInfo(663, TheLastMonarchII, "The Last Monarch II",
                       GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(727, RightAndLeft, "Right and Left",
                       GI.GT_PAIRING_TYPE, 2, -1, GI.SL_LUCK))
+registerGame(GameInfo(801, DoubleNestor, "Double Nestor",
+                      GI.GT_PAIRING_TYPE | GI.GT_OPEN, 2, 0,
+                      GI.SL_MOSTLY_LUCK))
+registerGame(GameInfo(810, Quatorze, "Quatorze",
+                      GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
