@@ -21,15 +21,11 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-
-# PySol imports
-from pysollib.mygettext import _
-from pysollib.gamedb import registerGame, GameInfo, GI
 from pysollib.game import Game
+from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.layout import Layout
+from pysollib.mygettext import _
 from pysollib.pysoltk import MfxCanvasText
-
 from pysollib.stack import \
         InitialDealTalonStack, \
         InvisibleStack, \
@@ -58,6 +54,8 @@ class PokerSquare(Game):
     Hint_Class = None
 
     WIN_SCORE = 100
+    NUM_RESERVE = 0
+    RESERVE_STACK = StackWrapper(ReserveStack, max_cards=5)
 
     #
     # game layout
@@ -76,16 +74,16 @@ class PokerSquare(Game):
                               text=_('''\
 Royal Flush
 Straight Flush
-Four of a Kind
+4 of a Kind
 Full House
 Flush
 Straight
-Three of a Kind
+3 of a Kind
 Two Pair
 One Pair'''))
             self.texts.list.append(t)
             bb = t.bbox()
-            x = bb[1][0] + 16
+            x = bb[1][0] + l.CW * 1.3
             h = bb[1][1] - bb[0][1]
             if h >= 2*l.YS:
                 ta = "e"
@@ -95,7 +93,7 @@ One Pair'''))
                               font=self.app.getFont("canvas_default"),
                               text="100\n75\n50\n25\n20\n15\n10\n5\n2")
             self.texts.list.append(t)
-            x = t.bbox()[1][0] + 16
+            x = t.bbox()[1][0] + l.CW * .6
             self.texts.misc = MfxCanvasText(
                 self.canvas, x, y, anchor="nw",
                 font=self.app.getFont("canvas_default"),
@@ -103,8 +101,8 @@ One Pair'''))
             x = self.texts.misc.bbox()[1][0] + 32
 
         # set window
-        w = max(2*l.XS, x)
-        self.setSize(l.XM + w + 5*l.XS + 50, l.YM + 5*l.YS + 30)
+        w = max(2 * l.XS, x, ((self.NUM_RESERVE + 1) * l.XS) + (4 * l.XM))
+        self.setSize(l.XM + w + 5 * l.XS + 50, l.YM + 5 * l.YS + 30)
 
         # create stacks
         for i in range(5):
@@ -116,6 +114,10 @@ One Pair'''))
         l.createText(s.talon, anchor=ta)
         s.internals.append(InvisibleStack(self))    # for _swapPairMove()
 
+        for i in range(self.NUM_RESERVE):
+            x, y = ((i + 1) * l.XS) + (2 * l.XM), l.YM
+            s.reserves.append(self.RESERVE_STACK(x, y, self))
+
         # create texts 2)
         if self.preview <= 1:
             for i in (4, 9, 14, 19, 24):
@@ -154,12 +156,21 @@ One Pair'''))
     #
 
     def startGame(self):
-        self.moveMove(27, self.s.talon, self.s.internals[0], frames=0)
+        self.moveMove(27 - (5 * self.NUM_RESERVE), self.s.talon,
+                      self.s.internals[0], frames=0)
         self.s.talon.fillStack()
 
+    def isBoardFull(self):
+        for i in range(25):
+            if len(self.s.rows[i].cards) == 0:
+                return False
+        return True
+
     def isGameWon(self):
-        return len(self.s.talon.cards) == 0 and \
-            self.getGameScore() >= self.WIN_SCORE
+        if self.isBoardFull():
+            return self.getGameScore() >= self.WIN_SCORE
+
+        return False
 
     def getAutoStacks(self, event=None):
         return ((), (), ())
@@ -176,19 +187,19 @@ One Pair'''))
         for i in range(10):
             type, value = self.getHandScore(self.poker_hands[i])
             if 0 <= type <= 8:
-                count[type] = count[type] + 1
+                count[type] += 1
             self.texts.list[i+2].config(text=str(value))
-            score = score + value
+            score += value
         t = '\n'.join(map(str, count))
         self.texts.misc.config(text=t)
         #
         t = ""
         if score >= self.WIN_SCORE:
             t = _("WON\n\n")
-        if self.s.talon.cards:
-            t = t + _("Points: %d") % score
+        if not self.isBoardFull():
+            t += _("Points: %d") % score
         else:
-            t = t + _("Total: %d") % score
+            t += _("Total: %d") % score
         self.texts.score.config(text=t)
 
     def getGameScore(self):
@@ -281,6 +292,25 @@ class PokerShuffle(PokerSquare):
     def checkForWin(self):
         return 0
 
+# ************************************************************************
+# * Poker Square (Waste)
+# * Poker Square (1 Reserve)
+# * Poker Square (2 Reserves)
+# ************************************************************************
+
+
+class PokerSquareWaste(PokerSquare):
+    NUM_RESERVE = 1
+    RESERVE_STACK = StackWrapper(ReserveStack, max_cards=5, max_move=0)
+
+
+class PokerSquare1Reserve(PokerSquare):
+    NUM_RESERVE = 1
+
+
+class PokerSquare2Reserves(PokerSquare):
+    NUM_RESERVE = 2
+
 
 # register the game
 registerGame(GameInfo(139, PokerSquare, "Poker Square",
@@ -290,3 +320,12 @@ registerGame(GameInfo(140, PokerShuffle, "Poker Shuffle",
                       GI.GT_POKER_TYPE | GI.GT_SCORE | GI.GT_OPEN, 1, 0,
                       GI.SL_MOSTLY_SKILL,
                       si={"ncards": 25}))
+registerGame(GameInfo(797, PokerSquareWaste, "Poker Square (Waste)",
+                      GI.GT_POKER_TYPE | GI.GT_SCORE, 1, 0, GI.SL_MOSTLY_SKILL,
+                      si={"ncards": 30}, rules_filename="pokersquare.html"))
+registerGame(GameInfo(798, PokerSquare1Reserve, "Poker Square (1 Reserve)",
+                      GI.GT_POKER_TYPE | GI.GT_SCORE, 1, 0, GI.SL_MOSTLY_SKILL,
+                      si={"ncards": 30}, rules_filename="pokersquare.html"))
+registerGame(GameInfo(799, PokerSquare2Reserves, "Poker Square (2 Reserves)",
+                      GI.GT_POKER_TYPE | GI.GT_SCORE, 1, 0, GI.SL_MOSTLY_SKILL,
+                      si={"ncards": 35}, rules_filename="pokersquare.html"))
