@@ -43,6 +43,21 @@ import validate
 # * Options
 # ************************************************************************
 
+_global_settings = {
+    'mouse_button1': 1,
+    'mouse_button2': 2,
+    'mouse_button3': 3,
+}
+
+
+def calcCustomMouseButtonsBinding(binding_format):
+    assert _global_settings['mouse_button1']
+    return binding_format.format(
+        mouse_button1=_global_settings['mouse_button1'],
+        mouse_button2=_global_settings['mouse_button2'],
+        mouse_button3=_global_settings['mouse_button3'],
+    )
+
 
 configspec = '''
 [general]
@@ -104,6 +119,7 @@ sound = boolean
 sound_mode = integer(0, 1)
 sound_sample_volume = integer(0, 128)
 sound_sample_buffer_size = integer(1, 4)
+music = boolean
 tabletile_name = string
 recent_gameid = int_list
 favorite_gameid = int_list
@@ -138,6 +154,7 @@ gamewon = boolean
 droppair = boolean
 redo = boolean
 dealwaste = boolean
+extra = boolean
 
 [fonts]
 sans = list
@@ -246,6 +263,7 @@ class Options:
         ('sound_sample_volume', 'int'),
         ('sound_music_volume', 'int'),
         ('sound_sample_buffer_size', 'int'),
+        ('music', 'bool'),
         ('tabletile_name', 'str'),
         ('translate_game_names', 'bool'),
         ('solver_presets', 'list'),
@@ -253,6 +271,9 @@ class Options:
         ('solver_max_iterations', 'int'),
         ('solver_iterations_output_step', 'int'),
         ('solver_preset', 'string'),
+        ('mouse_button1', 'int'),
+        ('mouse_button2', 'int'),
+        ('mouse_button3', 'int'),
         # ('toolbar_vars', 'list'),
         # ('recent_gameid', 'list'),
         # ('favorite_gameid', 'list'),
@@ -320,6 +341,9 @@ class Options:
         self.num_cards = False
         self.helpbar = False
         self.splashscreen = True
+        self.mouse_button1 = 1
+        self.mouse_button2 = 2
+        self.mouse_button3 = 3
         self.mouse_type = 'drag-n-drop'  # or 'sticky-mouse' or 'point-n-click'
         self.mouse_undo = False         # use mouse for undo/redo
         self.negative_bottom = True
@@ -332,6 +356,7 @@ class Options:
         self.sound_sample_volume = 75
         self.sound_music_volume = 100
         self.sound_sample_buffer_size = 1  # 1 - 4 (1024 - 4096 bytes)
+        self.music = True
         self.sound_samples = {
             'areyousure': True,
             'autodrop': True,
@@ -342,7 +367,7 @@ class Options:
             'dealwaste': True,
             'droppair': True,
             'drop': True,
-            # 'extra': True,
+            'extra': True,
             'flip': True,
             'move': True,
             'nomove': True,
@@ -414,6 +439,8 @@ class Options:
         self.scale_x = 1.0
         self.scale_y = 1.0
         self.auto_scale = False
+        self.spread_stacks = False
+        self.center_layout = True
         self.preserve_aspect_ratio = True
         # solver
         self.solver_presets = [
@@ -553,7 +580,8 @@ class Options:
         for key, val in self.cardset.items():
             config['cardsets'][str(key)] = val
         for key in ('scale_cards', 'scale_x', 'scale_y',
-                    'auto_scale', 'preserve_aspect_ratio'):
+                    'auto_scale', 'spread_stacks',
+                    'preserve_aspect_ratio'):
             config['cardsets'][key] = getattr(self, key)
 
         # games_geometry
@@ -631,7 +659,7 @@ class Options:
         vdt = validate.Validator()
         res = config.validate(vdt)
         # from pprint import pprint; pprint(res)
-        if res is not True:
+        if isinstance(res, dict):
             for section, data in res.items():
                 if data is True:
                     continue
@@ -723,6 +751,7 @@ class Options:
                        ('scale_x', 'float'),
                        ('scale_y', 'float'),
                        ('auto_scale', 'bool'),
+                       ('spread_stacks', 'bool'),
                        ('preserve_aspect_ratio', 'bool')):
             val = self._getOption('cardsets', key, t)
             if val is not None:
@@ -751,3 +780,20 @@ class Options:
                 self.offsets[key] = val
             except Exception:
                 traceback.print_exc()
+
+        # mouse buttons swap
+        def _positive(button):
+            return max([button, 1])
+        _global_settings['mouse_button1'] = _positive(self.mouse_button1)
+        _global_settings['mouse_button2'] = _positive(self.mouse_button2)
+        _global_settings['mouse_button3'] = _positive(self.mouse_button3)
+
+    def calcCustomMouseButtonsBinding(self, binding_format):
+        """docstring for calcCustomMouseButtonsBinding"""
+        def _positive(button):
+            return max([button, 1])
+        return binding_format.format(
+            mouse_button1=_positive(self.mouse_button1),
+            mouse_button2=_positive(self.mouse_button2),
+            mouse_button3=_positive(self.mouse_button3),
+        )
