@@ -21,26 +21,20 @@
 #
 # ---------------------------------------------------------------------------##
 
-
-# imports
-import os
-import sys
 import glob
+import os
 import traceback
 
-# PySol imports
-from pysollib.mfxutil import Struct, KwStruct
+from pysollib.mfxutil import KwStruct, Struct
+from pysollib.mygettext import _
 from pysollib.settings import DEBUG
 
-from pysollib.mygettext import _
+import six
 
 # ************************************************************************
 # * Abstract
 # ************************************************************************
 
-if sys.version_info > (3,):
-    basestring = str
-
 
 class Resource(Struct):
     def __init__(self, **kw):
@@ -129,6 +123,8 @@ class ResourceManager:
             pass
 
     def getSearchDirs(self, app, search, env=None):
+        """Get a list of normalized directory paths. The returned list has no
+        duplicates."""
         if isinstance(search, str):
             search = (search,)
         result = []
@@ -172,6 +168,7 @@ class CSI:
     SIZE_MEDIUM = 3
     SIZE_LARGE = 4
     SIZE_XLARGE = 5
+    SIZE_HIRES = 6
 
     # cardset types
     TYPE_FRENCH = 1
@@ -386,7 +383,7 @@ class Cardset(Resource):
 
     def updateCardback(self, backname=None, backindex=None):
         # update default back
-        if isinstance(backname, basestring):
+        if isinstance(backname, six.string_types):
             if backname in self.backnames:
                 backindex = self.backnames.index(backname)
         if isinstance(backindex, int):
@@ -481,8 +478,10 @@ class CardsetManager(ResourceManager):
                 cs.si.size = CSI.SIZE_MEDIUM
             elif CW <= 90 and CH <= 125:
                 cs.si.size = CSI.SIZE_LARGE
-            else:
+            elif CW <= 150 and CH <= 210:
                 cs.si.size = CSI.SIZE_XLARGE
+            else:
+                cs.si.size = CSI.SIZE_HIRES
         #
         keys = cs.styles[:]
         cs.si.styles = tuple([s for s in keys if s in CSI.STYLE])
