@@ -109,7 +109,7 @@ class SelectGameData(SelectDialogTreeData):
                                 select_mahjongg_game)
         g.append(gg)
         if g[0]:
-            s_by_type = SelectGameNode(None, _("French games"),
+            s_by_type = SelectGameNode(None, _("French Games"),
                                        tuple(g[0]), expanded=1)
         if g[1]:
             s_oriental = SelectGameNode(None, _("Oriental Games"),
@@ -513,7 +513,7 @@ class SelectGameDialogWithPreview(SelectGameDialog):
         # self.top.wm_title("Select Game - " +
         #   self.app.getGameTitleName(gameid))
         title = self.app.getGameTitleName(gameid)
-        self.top.wm_title(_("Playable Preview - %(game)s") % {'game': title})
+        self.top.wm_title(_("Select Game - %(game)s") % {'game': title})
         #
         self.preview_game = gi.gameclass(gi)
         self.preview_game.createPreview(self.preview_app)
