@@ -171,6 +171,8 @@ class PysolMenubarTkCommon:
             shisen_show_hint=tkinter.BooleanVar(),
             sound=tkinter.BooleanVar(),
             auto_scale=tkinter.BooleanVar(),
+            spread_stacks=tkinter.BooleanVar(),
+            center_layout=tkinter.BooleanVar(),
             cardback=tkinter.IntVar(),
             tabletile=tkinter.IntVar(),
             animations=tkinter.IntVar(),
@@ -222,6 +224,8 @@ class PysolMenubarTkCommon:
         tkopt.shisen_show_hint.set(opt.shisen_show_hint)
         tkopt.sound.set(opt.sound)
         tkopt.auto_scale.set(opt.auto_scale)
+        tkopt.spread_stacks.set(opt.spread_stacks)
+        tkopt.center_layout.set(opt.center_layout)
         tkopt.cardback.set(self.app.cardset.backindex)
         tkopt.tabletile.set(self.app.tabletile_index)
         tkopt.animations.set(opt.animations)
@@ -514,14 +518,8 @@ class PysolMenubarTkCommon:
             command=self.mOptShisenShowHint)
         menu.add_separator()
         label = n_("&Sound...")
-        if not self.app.audio.CAN_PLAY_SOUND:
-            menu.add_checkbutton(
-                label=label, variable=self.tkopt.sound,
-                command=self.mOptSoundDialog, state='disabled')
-        else:
-            menu.add_checkbutton(
-                label=label, variable=self.tkopt.sound,
-                command=self.mOptSoundDialog)
+        menu.add_command(
+            label=label, command=self.mOptSoundDialog)
         # cardsets
         if USE_PIL:
             submenu = MfxMenu(menu, label=n_("Card si&ze"))
@@ -534,6 +532,13 @@ class PysolMenubarTkCommon:
             submenu.add_checkbutton(
                 label=n_("&Auto scaling"), variable=self.tkopt.auto_scale,
                 command=self.mOptAutoScale, accelerator=m+'0')
+            submenu = MfxMenu(menu, label=n_("Card la&yout"))
+            submenu.add_checkbutton(
+                label=n_("&Spread stacks"), variable=self.tkopt.spread_stacks,
+                command=self.mOptSpreadStacks)
+            submenu.add_checkbutton(
+                label=n_("&Center layout"), variable=self.tkopt.center_layout,
+                command=self.mOptCenterLayout)
         # manager = self.app.cardset_manager
         # n = manager.len()
         menu.add_command(
@@ -646,10 +651,16 @@ class PysolMenubarTkCommon:
         if self.progress:
             self.progress.update(step=1)
 
+        # macOS: tk creates the menu item "Help->PySolFC Help", therefore
+        # we will not create a duplicate "Help->Contents" item.
+        # The tk-provided menu item expects this callback.
+        self.top.createcommand('tk::mac::ShowHelp', self.mHelp)
+
         menu = MfxMenu(self.menubar, label=n_("&Help"))
-        menu.add_command(
-            label=n_("&Contents"),
-            command=self.mHelp, accelerator=m+"F1")
+        if WIN_SYSTEM != "aqua":
+            menu.add_command(
+                label=n_("&Contents"),
+                command=self.mHelp, accelerator=m+"F1")
         menu.add_command(
             label=n_("&How to play"),
             command=self.mHelpHowToPlay)
@@ -748,15 +759,6 @@ class PysolMenubarTkCommon:
     #
 
     def _bindKey(self, modifier, key, func):
-        #  if 0 and not modifier and len(key) == 1:
-        #      self.keybindings[key.lower()] = func
-        #      self.keybindings[key.upper()] = func
-        #      return
-        if not modifier and len(key) == 1:
-            # ignore Ctrl/Shift/Alt
-            # but don't ignore NumLock (state == 16)
-            def func(e, f2=func):
-                return e.state in (0, 16) and f2(e)
         sequence = "<" + modifier + "KeyPress-" + key + ">"
         bind(self.top, sequence, func)
         if len(key) == 1 and key != key.upper():
@@ -793,9 +795,7 @@ class PysolMenubarTkCommon:
         m = "Ctrl-"
         if sys.platform == "darwin":
             m = "Cmd-"
-        menu.add_command(label=n_("All &games..."), accelerator=m+"W",
-                         command=self.mSelectGameDialog)
-        menu.add_command(label=n_("Playable pre&view..."), accelerator=m+"V",
+        menu.add_command(label=n_("All &games..."), accelerator=m+"V",
                          command=self.mSelectGameDialogWithPreview)
         if not SELECT_GAME_MENU:
             return
@@ -1433,10 +1433,12 @@ Unsupported game for import.
         geom = (self.app.canvas.winfo_width(),
                 self.app.canvas.winfo_height())
         self.app.opt.game_geometry = geom
-        self.app.game.resizeGame()
-        if self.app.opt.auto_scale:
+        self.app.game.resizeGame(card_size_manually=True)
+        if self.app.opt.auto_scale or self.app.opt.spread_stacks:
             w, h = self.app.opt.game_geometry
             self.app.canvas.setInitialSize(w, h, scrollregion=False)
+            # Resize a second time to auto scale
+            self.app.game.resizeGame(card_size_manually=False)
         else:
             w = int(round(self.app.game.width * self.app.opt.scale_x))
             h = int(round(self.app.game.height * self.app.opt.scale_y))
@@ -1478,10 +1480,36 @@ Unsupported game for import.
         if self._cancelDrag(break_pause=True):
             return
         auto_scale = not self.app.opt.auto_scale
+
+        # In the future, it should be possible to use both options together,
+        # but the current logic conflicts, so not allowed for now.
+        self.app.opt.spread_stacks = False
+        self.tkopt.spread_stacks.set(False)
+
         self.app.opt.auto_scale = auto_scale
         self.tkopt.auto_scale.set(auto_scale)
         self._updateCardSize()
 
+    def mOptSpreadStacks(self, *event):
+        if self._cancelDrag(break_pause=True):
+            return
+        spread_stacks = not self.app.opt.spread_stacks
+
+        # In the future, it should be possible to use both options together,
+        # but the current logic conflicts, so not allowed for now.
+        self.app.opt.auto_scale = False
+        self.tkopt.auto_scale.set(False)
+
+        self.app.opt.spread_stacks = spread_stacks
+        self.tkopt.spread_stacks.set(spread_stacks)
+        self._updateCardSize()
+
+    def mOptCenterLayout(self, *event):
+        if self._cancelDrag(break_pause=True):
+            return
+        self.app.opt.center_layout = not self.app.opt.center_layout
+        self._updateCardSize()
+
     def _mOptCardback(self, index):
         if self._cancelDrag(break_pause=False):
             return
