@@ -429,11 +429,15 @@ class MyCustomGame(CustomGame):
                     # escape
                     v = v.replace('\\', '\\\\')
                     v = v.replace("'", "\\'")
-                    if isinstance(v, six.text_type):
-                        v = v.encode('utf-8')
+                    v = v.replace("\n", "\\n")
+                    v = v.replace("\r", "\\r")
+                    v = v.replace("\t", "\\t")
+                    # See: https://github.com/shlomif/PySolFC/issues/177
+                    # if isinstance(v, six.text_type):
+                    #     v = v.encode('utf-8')
                     if not v:
                         v = 'Invalid Game Name'
-                fd.write("        '%s': '%s',\n" % (w.var_name, v))
+                fd.write("        '{}': '{}',\n".format(w.var_name, v))
         fd.write("        'gameid': %i,\n" % gameid)
 
         fd.write('''\
